@@ -491,6 +491,400 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeCaptchaMiniDataRequest(AbstractModel):
+    """DescribeCaptchaMiniData请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaAppId: 验证码应用ID
+        :type CaptchaAppId: int
+        :param Start: 查询开始时间
+        :type Start: int
+        :param End: 查询结束时间
+        :type End: int
+        :param Type: 查询类型
+        :type Type: int
+        """
+        self.CaptchaAppId = None
+        self.Start = None
+        self.End = None
+        self.Type = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaAppId = params.get("CaptchaAppId")
+        self.Start = params.get("Start")
+        self.End = params.get("End")
+        self.Type = params.get("Type")
+
+
+class DescribeCaptchaMiniDataResponse(AbstractModel):
+    """DescribeCaptchaMiniData返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaCode: 返回码 0 成功 其它失败
+        :type CaptchaCode: int
+        :param Data: 数据数组
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Data: list of CaptchaQueryData
+        :param CaptchaMsg: 返回信息描述
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CaptchaMsg: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.CaptchaCode = None
+        self.Data = None
+        self.CaptchaMsg = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaCode = params.get("CaptchaCode")
+        if params.get("Data") is not None:
+            self.Data = []
+            for item in params.get("Data"):
+                obj = CaptchaQueryData()
+                obj._deserialize(item)
+                self.Data.append(obj)
+        self.CaptchaMsg = params.get("CaptchaMsg")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeCaptchaMiniDataSumRequest(AbstractModel):
+    """DescribeCaptchaMiniDataSum请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaAppId: 验证码应用ID
+        :type CaptchaAppId: int
+        :param Start: 查询开始时间
+        :type Start: int
+        :param End: 查询结束时间
+        :type End: int
+        """
+        self.CaptchaAppId = None
+        self.Start = None
+        self.End = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaAppId = params.get("CaptchaAppId")
+        self.Start = params.get("Start")
+        self.End = params.get("End")
+
+
+class DescribeCaptchaMiniDataSumResponse(AbstractModel):
+    """DescribeCaptchaMiniDataSum返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param GetSum: 请求总量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type GetSum: int
+        :param VfySuccSum: 请求验证成功量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VfySuccSum: int
+        :param VfySum: 请求验证量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VfySum: int
+        :param AttackSum: 拦截攻击量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AttackSum: int
+        :param CaptchaMsg: 返回信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CaptchaMsg: str
+        :param CaptchaCode: 成功返回0  其它失败
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CaptchaCode: int
+        :param CheckTicketSum: 票据校验总量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CheckTicketSum: int
+        :param TicketThroughputSum: 票据验证通过量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TicketThroughputSum: int
+        :param TicketInterceptSum: 票据验证拦截量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TicketInterceptSum: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.GetSum = None
+        self.VfySuccSum = None
+        self.VfySum = None
+        self.AttackSum = None
+        self.CaptchaMsg = None
+        self.CaptchaCode = None
+        self.CheckTicketSum = None
+        self.TicketThroughputSum = None
+        self.TicketInterceptSum = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.GetSum = params.get("GetSum")
+        self.VfySuccSum = params.get("VfySuccSum")
+        self.VfySum = params.get("VfySum")
+        self.AttackSum = params.get("AttackSum")
+        self.CaptchaMsg = params.get("CaptchaMsg")
+        self.CaptchaCode = params.get("CaptchaCode")
+        self.CheckTicketSum = params.get("CheckTicketSum")
+        self.TicketThroughputSum = params.get("TicketThroughputSum")
+        self.TicketInterceptSum = params.get("TicketInterceptSum")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeCaptchaMiniOperDataRequest(AbstractModel):
+    """DescribeCaptchaMiniOperData请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaAppId: 验证码应用ID
+        :type CaptchaAppId: int
+        :param Start: 查询开始时间
+        :type Start: int
+        :param Type: 查询类型
+        :type Type: int
+        """
+        self.CaptchaAppId = None
+        self.Start = None
+        self.Type = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaAppId = params.get("CaptchaAppId")
+        self.Start = params.get("Start")
+        self.Type = params.get("Type")
+
+
+class DescribeCaptchaMiniOperDataResponse(AbstractModel):
+    """DescribeCaptchaMiniOperData返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaCode: 成功返回 0 其它失败
+        :type CaptchaCode: int
+        :param CaptchaMsg: 返回信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CaptchaMsg: str
+        :param Data: 用户操作数据
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Data: :class:`tencentcloud.captcha.v20190722.models.CaptchaOperDataRes`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.CaptchaCode = None
+        self.CaptchaMsg = None
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaCode = params.get("CaptchaCode")
+        self.CaptchaMsg = params.get("CaptchaMsg")
+        if params.get("Data") is not None:
+            self.Data = CaptchaOperDataRes()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeCaptchaMiniResultRequest(AbstractModel):
+    """DescribeCaptchaMiniResult请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaType: 固定填值：9（滑块验证码）
+        :type CaptchaType: int
+        :param Ticket: 验证码返回给用户的票据
+        :type Ticket: str
+        :param UserIp: 用户操作来源的外网 IP
+        :type UserIp: str
+        :param CaptchaAppId: 验证码应用APPID
+        :type CaptchaAppId: int
+        :param AppSecretKey: 用于服务器端校验验证码票据的验证密钥，请妥善保密，请勿泄露给第三方
+        :type AppSecretKey: str
+        :param BusinessId: 业务 ID，网站或应用在多个业务中使用此服务，通过此 ID 区分统计数据
+        :type BusinessId: int
+        :param SceneId: 场景 ID，网站或应用的业务下有多个场景使用此服务，通过此 ID 区分统计数据
+        :type SceneId: int
+        :param MacAddress: mac 地址或设备唯一标识
+        :type MacAddress: str
+        :param Imei: 手机设备号
+        :type Imei: str
+        """
+        self.CaptchaType = None
+        self.Ticket = None
+        self.UserIp = None
+        self.CaptchaAppId = None
+        self.AppSecretKey = None
+        self.BusinessId = None
+        self.SceneId = None
+        self.MacAddress = None
+        self.Imei = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaType = params.get("CaptchaType")
+        self.Ticket = params.get("Ticket")
+        self.UserIp = params.get("UserIp")
+        self.CaptchaAppId = params.get("CaptchaAppId")
+        self.AppSecretKey = params.get("AppSecretKey")
+        self.BusinessId = params.get("BusinessId")
+        self.SceneId = params.get("SceneId")
+        self.MacAddress = params.get("MacAddress")
+        self.Imei = params.get("Imei")
+
+
+class DescribeCaptchaMiniResultResponse(AbstractModel):
+    """DescribeCaptchaMiniResult返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaCode: 1       ticket verification succeeded     票据验证成功
+7       CaptchaAppId does not match     票据与验证码应用APPID不匹配
+8       ticket expired     票据超时
+10     ticket format error     票据格式不正确
+15     ticket decryption failed     票据解密失败
+16     CaptchaAppId wrong format     检查验证码应用APPID错误
+21     ticket error     票据验证错误
+26     system internal error     系统内部错误
+100   param err     参数校验错误
+        :type CaptchaCode: int
+        :param CaptchaMsg: 状态描述及验证错误信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CaptchaMsg: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.CaptchaCode = None
+        self.CaptchaMsg = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaCode = params.get("CaptchaCode")
+        self.CaptchaMsg = params.get("CaptchaMsg")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeCaptchaMiniRiskResultRequest(AbstractModel):
+    """DescribeCaptchaMiniRiskResult请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaType: 固定填值：9（滑块验证码）
+        :type CaptchaType: int
+        :param Ticket: 验证码返回给用户的票据
+        :type Ticket: str
+        :param UserIp: 用户操作来源的外网 IP
+        :type UserIp: str
+        :param CaptchaAppId: 验证码应用APPID
+        :type CaptchaAppId: int
+        :param AppSecretKey: 用于服务器端校验验证码票据的验证密钥，请妥善保密，请勿泄露给第三方
+        :type AppSecretKey: str
+        :param BusinessId: 业务 ID，网站或应用在多个业务中使用此服务，通过此 ID 区分统计数据
+        :type BusinessId: int
+        :param SceneId: 场景 ID，网站或应用的业务下有多个场景使用此服务，通过此 ID 区分统计数据
+        :type SceneId: int
+        :param MacAddress: mac 地址或设备唯一标识
+        :type MacAddress: str
+        :param Imei: 手机设备号
+        :type Imei: str
+        :param SceneCode: 验证场景：1 活动防刷场景，2 登录保护场景，3 注册保护场景。根据需求选择场景参数。
+        :type SceneCode: int
+        :param WeChatOpenId: 用户操作来源的微信开放账号
+        :type WeChatOpenId: str
+        """
+        self.CaptchaType = None
+        self.Ticket = None
+        self.UserIp = None
+        self.CaptchaAppId = None
+        self.AppSecretKey = None
+        self.BusinessId = None
+        self.SceneId = None
+        self.MacAddress = None
+        self.Imei = None
+        self.SceneCode = None
+        self.WeChatOpenId = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaType = params.get("CaptchaType")
+        self.Ticket = params.get("Ticket")
+        self.UserIp = params.get("UserIp")
+        self.CaptchaAppId = params.get("CaptchaAppId")
+        self.AppSecretKey = params.get("AppSecretKey")
+        self.BusinessId = params.get("BusinessId")
+        self.SceneId = params.get("SceneId")
+        self.MacAddress = params.get("MacAddress")
+        self.Imei = params.get("Imei")
+        self.SceneCode = params.get("SceneCode")
+        self.WeChatOpenId = params.get("WeChatOpenId")
+
+
+class DescribeCaptchaMiniRiskResultResponse(AbstractModel):
+    """DescribeCaptchaMiniRiskResult返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CaptchaCode: 1 ticket verification succeeded 票据验证成功
+7 CaptchaAppId does not match 票据与验证码应用APPID不匹配
+8 ticket expired 票据超时
+10 ticket format error 票据格式不正确
+15 ticket decryption failed 票据解密失败
+16 CaptchaAppId wrong format 检查验证码应用APPID错误
+21 ticket error 票据验证错误
+25 bad visitor 策略拦截
+26 system internal error 系统内部错误
+100 param err 参数校验错误
+        :type CaptchaCode: int
+        :param CaptchaMsg: 状态描述及验证错误信息
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CaptchaMsg: str
+        :param ManageMarketingRiskValue: 拦截策略返回信息
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ManageMarketingRiskValue: :class:`tencentcloud.captcha.v20190722.models.OutputManageMarketingRiskValue`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.CaptchaCode = None
+        self.CaptchaMsg = None
+        self.ManageMarketingRiskValue = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.CaptchaCode = params.get("CaptchaCode")
+        self.CaptchaMsg = params.get("CaptchaMsg")
+        if params.get("ManageMarketingRiskValue") is not None:
+            self.ManageMarketingRiskValue = OutputManageMarketingRiskValue()
+            self.ManageMarketingRiskValue._deserialize(params.get("ManageMarketingRiskValue"))
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeCaptchaOperDataRequest(AbstractModel):
     """DescribeCaptchaOperData请求参数结构体
 
@@ -759,6 +1153,80 @@ class DescribeCaptchaUserAllAppIdResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class OutputManageMarketingRiskValue(AbstractModel):
+    """拦截策略返回信息
+
+    """
+
+    def __init__(self):
+        """
+        :param UserId: 账号 ID。对应输入参数： AccountType 是 1 时，对应 QQ 的 OpenID。
+AccountType 是 2 时，对应微信的 OpenID/UnionID。
+AccountType 是 4 时，对应手机号。
+AccountType 是 8 时，对应 imei、idfa、imeiMD5 或者 idfaMD5。
+AccountType 是 0 时，对应账号信息。
+AccountType 是 10004 时，对应手机号的 MD5。
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UserId: str
+        :param PostTime: 操作时间戳，单位秒（对应输入参数）。 
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PostTime: int
+        :param AssociateAccount: 对应输入参数，AccountType 是 QQ 或微信开放账号时，用于标识 QQ 或微信用户登录 后关联业务自身的账号 ID。
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AssociateAccount: str
+        :param UserIp: 业务详情。 注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UserIp: str
+        :param RiskLevel: 风险值 pass : 无恶意
+review：需要人工审核
+reject：拒绝，高风险恶意
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RiskLevel: str
+        :param RiskType: 风险类型，请查看下面详细说明 注意：此字段可能返回 null，表示取不到有效值。
+账号风险	
+        账号信用低	1	账号近期存在因恶意被处罚历史，网络低活跃，被举报等因素
+	疑似 低活跃账号	11	账号活跃度与正常用户有差异
+	垃圾账号	2	疑似批量注册小号，近期存在严重违规或大量举报
+	疑似小号	21	账号有疑似线上养号，小号等行为
+	疑似 违规账号	22	账号曾有违规行为、曾被举报过、曾因违规被处罚过等
+	无效账号	3	送检账号参数无法成功解析，请检查微信 openid 是否有
+	黑名单	4	该账号在业务侧有过拉黑记录
+	白名单 	5	业务自行有添加过白名单记录
+行为风险	
+        批量操作	101	存在 ip/设备/环境等因素的聚集性异常
+	疑似 IP 属性聚集 	1011	出现 IP 聚集
+	疑似 设备属性聚集 	1012	出现设备聚集
+	自动机 	103	疑似自动机批量请求
+	微信登录态无效 	104	检查 wxtoken 参数，是否已经失效
+环境风险	
+        环境异常 	201	操作 ip/设备/环境存在异常。当前 ip 为非常用 ip 或恶意 ip 段
+	疑似 非常用IP请求 	2011	当前请求 IP 非该账号常用 IP
+	疑似 IP 异常 	2012	使用 idc 机房 ip 或 使用代理 ip 或 使用恶意 ip 
+	非公网有效 ip 	205	传进来的 IP 地址为内网 ip 地址或者 ip 保留地
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RiskType: list of int
+        """
+        self.UserId = None
+        self.PostTime = None
+        self.AssociateAccount = None
+        self.UserIp = None
+        self.RiskLevel = None
+        self.RiskType = None
+
+
+    def _deserialize(self, params):
+        self.UserId = params.get("UserId")
+        self.PostTime = params.get("PostTime")
+        self.AssociateAccount = params.get("AssociateAccount")
+        self.UserIp = params.get("UserIp")
+        self.RiskLevel = params.get("RiskLevel")
+        self.RiskType = params.get("RiskType")
+
+
 class TicketAmountUnit(AbstractModel):
     """DescribeCaptchaTicketData 返回的数据结构
 
